@@ -6,12 +6,10 @@ app = Flask(__name__)
 flow_manager = FlowManager()
 
 
-@app.route("/flow-processor/<flow_name>/", methods=['POST'])
+@app.route("/flow-processor/<flow_name>/", methods=["POST"])
 def run_flow(flow_name):
     # flow_manager
     if not request.json:
         abort(400)
 
-    return jsonify({
-        "result": flow_manager.run(flow_name, request.json)
-    })
+    return jsonify({"result": flow_manager.run(flow_name, request.json["data"])})
